@@ -1,5 +1,8 @@
 package CGI::Builder ;
-$VERSION = 1.21 ;
+$VERSION = 1.22 ;
+
+# This file uses the "Perlish" coding style
+# please read http://perl.4pro.net/perlish_coding_style.html
 
 ; use strict
 ; use 5.006_001
@@ -106,7 +109,7 @@ $VERSION = 1.21 ;
       )
 
 ; our $AUTOLOAD
-; sub AUTOLOAD ($;$) : lvalue              # param AUTOLOADING
+; sub AUTOLOAD : lvalue              # param AUTOLOADING
    { (my $n = $AUTOLOAD) =~ s/.*://
    ; return if $n eq 'DESTROY'
    ; @_ == 2
@@ -226,9 +229,9 @@ __END__
 
 CGI::Builder - Framework to build simple or complex web-apps
 
-=head1 VERSION 1.21
+=head1 VERSION 1.22
 
-Included in CGI-Builder 1.21 distribution.
+Included in CGI-Builder 1.22 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -269,7 +272,7 @@ To have the complete list of all the extensions of the CBF, see L<"Extensions Li
 
 =item CPAN
 
-    perl -MCPAN -e 'install Apache::CGI::Builder'
+    perl -MCPAN -e 'install CGI::Builder'
 
 You have also the possibility to use the Bundle to install all the extensions and prerequisites of the CBF in just one step. Please, notice that the Bundle will install A LOT of modules that you might not need, so use it specially if you want to extensively try the CBF.
 
@@ -284,6 +287,8 @@ From the directory where this file is located, type:
     make test
     make install
 
+B<Note>: The installation of this module runs an automatic version check connection which will warn you in case a newer version is available: please don't use old versions, because I can give you full support only for current versions. Besides, since CPAN does not provide any download statistic to the authors, this check allows me also to keep my own installation counter. Version checking is transparent to regular users, while CPAN testers should skip it by running the Makefile.PL with NO_VERSION_CHECK=1.
+
 =back
 
 =head1 SYNOPSIS
